@@ -1,4 +1,4 @@
-from tyba_client.models import PVModelTypes, PVStorageModel, StorageModel
+from tyba_client.models import PVModelTypes, PVStorageModel, StandaloneStorageModel
 import requests
 from urllib.parse import urljoin
 
@@ -29,7 +29,7 @@ class Client(object):
                              json=model_json_dict,
                              headers={"Authorization": self._auth_header()})
 
-    def schedule_storage(self, storage_model: StorageModel):
+    def schedule_storage(self, storage_model: StandaloneStorageModel):
         model_json_dict = storage_model.to_dict()
         url = urljoin(self._base_url(), "schedule-storage")
         return requests.post(url,
