@@ -193,6 +193,27 @@ class StorageModel(object):
     storage_inputs: StorageInputs
     energy_prices: t.List[float]
 
+@dataclass_json
+@dataclass
+class AncillaryMarkets(object):
+    rrs_capacity_factor: t.Optional[float]
+    reg_up_capacity_factor: t.Optional[float]
+    reg_down_capacity_factor: t.Optional[float]
+    rrs_utilization: t.Optional[float]
+    reg_up_utilization: t.Optional[float]
+    reg_down_utilization: t.Optional[float]
+    rrs_prices: t.Optional[t.List[float]]
+    reg_up_prices: t.Optional[t.List[float]]
+    reg_down_prices: t.Optional[t.List[float]]
+    reserve_settlement_prices: t.List[float]
+
+@dataclass_json
+@dataclass
+class StandaloneStorageModel(StorageModel):
+    time_interval_mins: t.Optional[float] = opt_field()
+    ancillary_markets: t.Optional[AncillaryMarkets] = opt_field()
+
+
 @string_enum
 class StorageCoupling(Enum):
     ac = 'ac'
